Package: cvTools
Type: Package
Title: Cross-Validation Tools for Regression Models
Version: 0.3.3
Date: 2024-03-13
Depends: R (>= 2.11.0), lattice, robustbase
Imports: stats
Description: Tools that allow developers to write functions for
    cross-validation with minimal programming effort and assist
    users with model selection.
License: GPL (>= 2)
LazyLoad: yes
Authors@R: 
    person("Andreas", "Alfons",
           email = "alfons@ese.eur.nl",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-2513-3788"))
Author: Andreas Alfons [aut, cre] (<https://orcid.org/0000-0002-2513-3788>)
Maintainer: Andreas Alfons <alfons@ese.eur.nl>
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2024-03-13 11:49:07 UTC; andreas
Repository: CRAN
Date/Publication: 2024-03-13 12:40:04 UTC
Built: R 4.6.0; ; 2026-04-25 23:48:37 UTC; unix
